#!/usr/bin/env node
'use strict';

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _rest = require('@octokit/rest');

var _rest2 = _interopRequireDefault(_rest);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _cli = require('../cli');

var _cli2 = _interopRequireDefault(_cli);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _prepend = require('prepend');

var _prepend2 = _interopRequireDefault(_prepend);

var _util = require('util.promisify');

var _util2 = _interopRequireDefault(_util);

var _ensureCleanLocalGitState = require('../ensureCleanLocalGitState');

var _ensureCleanLocalGitState2 = _interopRequireDefault(_ensureCleanLocalGitState);

var _getMergedPullRequests = require('../getMergedPullRequests');

var _getMergedPullRequests2 = _interopRequireDefault(_getMergedPullRequests);

var _createChangelog = require('../createChangelog');

var _createChangelog2 = _interopRequireDefault(_createChangelog);

var _findRemoteAlias = require('../findRemoteAlias');

var _findRemoteAlias2 = _interopRequireDefault(_findRemoteAlias);

var _gitPromise = require('git-promise');

var _gitPromise2 = _interopRequireDefault(_gitPromise);

var _getPullRequestLabel = require('../getPullRequestLabel');

var _getPullRequestLabel2 = _interopRequireDefault(_getPullRequestLabel);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.version(_package2.default.version).option('--sloppy', 'Skip ensuring clean local git state.').option('--trace', 'Show stack traces for any error.').usage('<version-number>').parse(process.argv);

const changelogPath = _path2.default.join(process.cwd(), 'CHANGELOG.md');
const options = { sloppy: _commander2.default.sloppy, changelogPath };
const findRemoteAlias = (0, _findRemoteAlias2.default)({ git: _gitPromise2.default });
const githubClient = (0, _rest2.default)();
const getMergedPullRequests = (0, _getMergedPullRequests2.default)({ githubClient, git: _gitPromise2.default, getPullRequestLabel: _getPullRequestLabel2.default });
const getCurrentDate = () => new Date();
const packageInfo = require(_path2.default.join(process.cwd(), 'package.json'));
const dependencies = {
    githubClient,
    prependFile: (0, _util2.default)(_prepend2.default),
    packageInfo,
    ensureCleanLocalGitState: (0, _ensureCleanLocalGitState2.default)({ git: _gitPromise2.default, findRemoteAlias }),
    getMergedPullRequests,
    createChangelog: (0, _createChangelog2.default)({ getCurrentDate, packageInfo })
};
const cliAgent = (0, _cli2.default)(dependencies);

cliAgent.run(_commander2.default.args[0], options, dependencies).catch(error => {
    let message = `Error: ${error.message}`;

    if (_commander2.default.trace) {
        message = error.stack;
    }

    // eslint-disable-next-line no-console, no-warning-comments
    console.error(message);
    process.exitCode = 1;
});