'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = createCliAgent;

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

var _getGithubRepo = require('./getGithubRepo');

var _getGithubRepo2 = _interopRequireDefault(_getGithubRepo);

var _validLabels = require('./validLabels');

var _validLabels2 = _interopRequireDefault(_validLabels);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function stripTrailingEmptyLine(text) {
    if (text.lastIndexOf('\n\n') === text.length - 2) {
        return text.slice(0, -1);
    }

    return text;
}

function getValidLabels(prLogConfig) {
    if (prLogConfig && prLogConfig.validLabels) {
        return new Map(prLogConfig.validLabels);
    }

    return _validLabels2.default;
}

function validateVersionnumber(versionNumber) {
    if (!versionNumber) {
        throw new Error('version-number not specified');
    }
    if (_semver2.default.valid(versionNumber) === null) {
        throw new Error('version-number is invalid');
    }
}

function createCliAgent(dependencies) {
    let generateChangelog = (() => {
        var _ref = _asyncToGenerator(function* (options, githubRepo, validLabels, newVersionNumber) {
            if (!options.sloppy) {
                yield ensureCleanLocalGitState(githubRepo);
            }

            const pullRequests = yield getMergedPullRequests(githubRepo, validLabels);
            const changelog = createChangelog(newVersionNumber, validLabels, pullRequests, githubRepo);

            return stripTrailingEmptyLine(changelog);
        });

        return function generateChangelog(_x, _x2, _x3, _x4) {
            return _ref.apply(this, arguments);
        };
    })();

    const ensureCleanLocalGitState = dependencies.ensureCleanLocalGitState,
          getMergedPullRequests = dependencies.getMergedPullRequests,
          createChangelog = dependencies.createChangelog,
          packageInfo = dependencies.packageInfo,
          prependFile = dependencies.prependFile;


    return {
        run: (() => {
            var _ref2 = _asyncToGenerator(function* (newVersionNumber, options = {}) {
                const githubRepo = (0, _getGithubRepo2.default)(packageInfo.repository.url);
                const prLogConfig = packageInfo['pr-log'];
                const validLabels = getValidLabels(prLogConfig);

                validateVersionnumber(newVersionNumber);

                const changelog = yield generateChangelog(options, githubRepo, validLabels, newVersionNumber);
                yield prependFile(options.changelogPath, changelog);
            });

            return function run(_x5) {
                return _ref2.apply(this, arguments);
            };
        })()
    };
}