'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function formatLinkToPullRequest(pullRequestId, repo) {
    return `[#${pullRequestId}](https://github.com/${repo}/pull/${pullRequestId})`;
}

function formatPullRequest(pullRequest, repo) {
    return `* ${pullRequest.title} (${formatLinkToPullRequest(pullRequest.id, repo)})\n`;
}

function formatListOfPullRequests(pullRequests, repo) {
    return pullRequests.map(pr => formatPullRequest(pr, repo)).join('');
}

function formatSection(displayLabel, pullRequests, repo) {
    return `### ${displayLabel}\n\n${formatListOfPullRequests(pullRequests, repo)}\n`;
}

exports.default = ({ getCurrentDate, packageInfo }) => {
    const defaultDateFormat = 'MMMM D, YYYY';

    var _ref = packageInfo['pr-log'] || {},
        _ref$dateFormat = _ref.dateFormat;

    const dateFormat = _ref$dateFormat === undefined ? defaultDateFormat : _ref$dateFormat;


    return function createChangelog(newVersionNumber, validLabels, mergedPullRequests, repo) {
        const groupedPullRequests = _ramda2.default.groupBy(_ramda2.default.prop('label'), mergedPullRequests);
        const date = (0, _moment2.default)(getCurrentDate()).locale('en').format(dateFormat);
        const title = `## ${newVersionNumber} (${date})`;

        let changelog = `${title}\n\n`;

        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
            for (var _iterator = validLabels[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                const _ref2 = _step.value;

                var _ref3 = _slicedToArray(_ref2, 2);

                const label = _ref3[0];
                const displayLabel = _ref3[1];

                const pullRequests = groupedPullRequests[label];

                if (pullRequests) {
                    changelog += formatSection(displayLabel, pullRequests, repo);
                }
            }
        } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
        } finally {
            try {
                if (!_iteratorNormalCompletion && _iterator.return) {
                    _iterator.return();
                }
            } finally {
                if (_didIteratorError) {
                    throw _iteratorError;
                }
            }
        }

        return changelog;
    };
};