'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

exports.default = dependencies => {
    const git = dependencies.git,
          findRemoteAlias = dependencies.findRemoteAlias;


    function ensureCleanLocalCopy() {
        return git('status -s').then(status => {
            if (status.trim() !== '') {
                throw new Error('Local copy is not clean');
            }
        });
    }

    function ensureMasterBranch() {
        return git('rev-parse --abbrev-ref HEAD').then(branchName => {
            if (branchName.trim() !== 'master') {
                throw new Error('Not on master branch');
            }
        });
    }

    function fetchRemote(remoteAlias) {
        return git(`fetch ${remoteAlias}`);
    }

    function ensureLocalIsEqualToRemote(remoteAlias) {
        const remoteBranch = `${remoteAlias}/master`;

        return git(`rev-list --left-right master...${remoteBranch}`).then(result => {
            const commits = result.split('\n');

            let commitsAhead = 0;
            let commitsBehind = 0;

            commits.forEach(function (commit) {
                if (commit.trim().length > 0) {
                    if (commit.indexOf('>') === 0) {
                        commitsBehind += 1;
                    } else {
                        commitsAhead += 1;
                    }
                }
            });

            if (commitsAhead > 0 || commitsBehind > 0) {
                // eslint-disable-next-line max-len
                const errorMessage = `Local git master branch is ${commitsAhead} commits ahead and ${commitsBehind} commits behind of ${remoteBranch}`;

                throw new Error(errorMessage);
            }
        });
    }

    return (() => {
        var _ref = _asyncToGenerator(function* (githubRepo) {
            yield ensureCleanLocalCopy();
            yield ensureMasterBranch();

            const remoteAlias = yield findRemoteAlias(githubRepo);

            yield fetchRemote(remoteAlias);
            yield ensureLocalIsEqualToRemote(remoteAlias);
        });

        function ensureCleanLocalGitState(_x) {
            return _ref.apply(this, arguments);
        }

        return ensureCleanLocalGitState;
    })();
};