'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _gitUrlParse = require('git-url-parse');

var _gitUrlParse2 = _interopRequireDefault(_gitUrlParse);

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function isSameGitUrl(gitUrlA, gitUrlB) {
    const parsedUrlA = (0, _gitUrlParse2.default)(gitUrlA);
    const parsedUrlB = (0, _gitUrlParse2.default)(gitUrlB);
    const pathA = parsedUrlA.pathname.replace(/\.git$/, '');
    const pathB = parsedUrlB.pathname.replace(/\.git$/, '');

    return parsedUrlA.resource === parsedUrlB.resource && pathA === pathB;
}

function getGitUrl(githubRepo) {
    return `git://github.com/${githubRepo}.git`;
}

exports.default = ({ git }) => function findRemoteAlias(githubRepo) {
    const gitRemote = getGitUrl(githubRepo);

    return git('remote -v').then(output => {
        const remotes = output.split('\n').map(remote => {
            const tokens = remote.split(/\s/);

            return {
                alias: tokens[0],
                url: tokens[1]
            };
        });

        const matchedRemote = _ramda2.default.find(remote => {
            return remote.url && isSameGitUrl(gitRemote, remote.url);
        }, remotes);

        if (!matchedRemote) {
            throw new Error(`This local git repository doesn’t have a remote pointing to ${gitRemote}`);
        }

        return matchedRemote.alias;
    });
};