'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

exports.default = dependencies => {
    const git = dependencies.git,
          getPullRequestLabel = dependencies.getPullRequestLabel;


    function getLatestVersionTag() {
        return git('tag --list').then(function (result) {
            const tags = result.split('\n');
            const versionTags = tags.filter(tag => _semver2.default.valid(tag) && !_semver2.default.prerelease(tag));
            const orderedVersionTags = versionTags.sort(_semver2.default.compare);

            return orderedVersionTags[orderedVersionTags.length - 1];
        });
    }

    function getPullRequests(fromTag) {
        return git(`log --no-color --pretty=format:"%s (%b)" --merges ${fromTag}..HEAD`).then(result => {
            const mergeCommits = result.replace(/[\r\n]+\)/g, ')').split('\n');

            return mergeCommits.map(commit => commit.match(/^Merge pull request #(\d+) from (.*?) \((.*)\)$/u)).filter(matches => matches).map(matches => ({ id: matches[1], title: matches[3] }));
        });
    }

    function extendWithLabel(githubRepo, validLabels, pullRequests) {
        const promises = pullRequests.map((() => {
            var _ref = _asyncToGenerator(function* (pullRequest) {
                const label = yield getPullRequestLabel(githubRepo, validLabels, pullRequest.id, dependencies);

                return {
                    id: pullRequest.id,
                    title: pullRequest.title,
                    label
                };
            });

            return function (_x) {
                return _ref.apply(this, arguments);
            };
        })());

        return Promise.all(promises);
    }

    return (() => {
        var _ref2 = _asyncToGenerator(function* (githubRepo, validLabels) {
            const latestVersionTag = yield getLatestVersionTag();
            const pullRequests = yield getPullRequests(latestVersionTag);
            const pullRequestsWithLabels = yield extendWithLabel(githubRepo, validLabels, pullRequests);

            return pullRequestsWithLabels;
        });

        function getMergedPullRequests(_x2, _x3) {
            return _ref2.apply(this, arguments);
        }

        return getMergedPullRequests;
    })();
};